#!/bin/sh
# Licensed Materials - Property of IBM
# OCO Source Materials
# 09N6996
# (C) Copyright IBM Corp. 2008, 2010 All Rights Reserved
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.
#
if [ -n "$1" ]
then
    if [ -d "$1"  ]
    then
        TARGETDIR=$1
    else
        echo "Usage: grablogs <target_directory>"
        exit 33
    fi
else
    TARGETDIR="/tmp"
fi

DATEVAL=`date +%Y-%m-%d-%H-%M-%S`
HOSTNAME=`hostname -s`
FOLDERNAME=$TARGETDIR/dirlogs-${HOSTNAME}-$DATEVAL
rm -rf $FOLDERNAME 
mkdir $FOLDERNAME

OSType='Linux'
if [ `uname -s` = "AIX" ]
then
    OSType='AIX'
fi
#echo $OSType
 
if [ -n "$SMCLIUSER" ]
then
    if [ -n "$SMCLIPASSWORD" ]
    then
        SMCLI_CREDENTIAL="-user $SMCLIUSER -pw $SMCLIPASSWORD"
    fi
fi

# ***grab configs ***
grab_configs() {
    echo "Collecting Configuration Data.."
    # logging.properties
    mkdir -p $FOLDERNAME/lwi/conf
    cp -p /opt/ibm/director/lwi/conf/logging.properties $FOLDERNAME/lwi/conf
    mkdir -p $FOLDERNAME/lwi/conf/overrides
    cp -p /opt/ibm/director/lwi/conf/overrides/logging.properties $FOLDERNAME/lwi/conf/overrides
    mkdir -p $FOLDERNAME/agent/conf
    cp -p /opt/ibm/director/agent/conf/logging.properties $FOLDERNAME/agent/conf
    mkdir -p $FOLDERNAME/agent/conf/overrides
    cp -p /opt/ibm/director/agent/conf/overrides/logging.properties $FOLDERNAME/agent/conf/overrides
    
}

# ***grab version files
grab_version_files() {
    echo "Collecting Director Version Data.."
    cp -p /opt/ibm/director/version.* $FOLDERNAME
    cp -p /var/opt/tivoli/ep/version.key $FOLDERNAME 1>/dev/null 2>&1
}

# ***grab update manager features
grab_updatemgr_feature() {
    echo "Collecting Update Manager Feature Data.."
    /opt/ibm/director/lwi/bin/lwiupdatemgr.sh -listFeatures > $FOLDERNAME/updatemgr_feature.txt
    /opt/ibm/director/agent/bin/lwiupdatemgr.sh -listFeatures > $FOLDERNAME/updatemgr_agent_feature.txt
}

# ***grab server logs
grab_server_logs() {
    echo "Collecting Server Logs..."
    #Primary log and trace files
    cp -p -r /opt/ibm/director/lwi/logs/. $FOLDERNAME
    mkdir -p $FOLDERNAME/ffdc
    #copy entire ffdc directory
    cp -p -r /opt/ibm/director/data/ffdc/. $FOLDERNAME/ffdc
    
    #Ancillary log and trace files
    cp -p -r /opt/ibm/director/log/. $FOLDERNAME
    cp -p /tmp/dirupdater.log $FOLDERNAME 1>/dev/null 2>&1
    cp -p /var/log/dirinst.log $FOLDERNAME

    # <director_root>/cimom/log/ibm-ipmi.log (no such file)
    # <director_root>/cimom/log/adptlogs
    mkdir -p $FOLDERNAME/agentmanager
    cp -p -r /opt/ibm/director/lwi/runtime/agentmanager/logs/. $FOLDERNAME/agentmanager
    cp -p -r /opt/ibm/director/lwi/runtime/agentmanager/toolkit/logs/. $FOLDERNAME/agentmanager
    cp -p -r /opt/ibm/director/lwi/runtime/core/logs/. $FOLDERNAME
    mkdir -p $FOLDERNAME/eccbase
    cp -p -r /opt/ibm/director/lwi/runtime/core/workspace/.metadata/.plugins/com.ibm.director.mgr.updates.server/ecc/. $FOLDERNAME/eccbase 1>/dev/null 2>&1
    #<director_root>/tpm/config/logs 
    
    # ***grab migration logs from default location***
    mkdir -p $FOLDERNAME/migration
    cp -p -r /var/tmp/director_save_620/logs/. $FOLDERNAME/migration 1>/dev/null 2>&1
}

# *** grab common agent***
grab_common_agent_logs() {
    echo "Collecting Common Agent Logs..."
    mkdir -p $FOLDERNAME/agent
    cp -p -r /opt/ibm/director/agent/logs/. $FOLDERNAME/agent
    cp -p -r /opt/ibm/director/agent/log/. $FOLDERNAME/agent

    # ***grab CAS Agent service.sh output***
    /opt/ibm/director/agent/runtime/agent/toolkit/bin/service.sh 1>/dev/null 2>&1
    cp -p /opt/ibm/director/agent/runtime/agent/CASservice.zip $FOLDERNAME/agent 1>/dev/null 2>&1

}

# *** grab platfrom(denali) agent
grab_platform_agent_logs() {
    echo "Collecting Platform Agent Logs..."
    mkdir -p $FOLDERNAME/platform_agent
    if [ "$OSType" = "Linux" ]
    then
        cp -r /opt/ibm/platform/version.lv1 $FOLDERNAME/platform_agent
        value=$(cat /etc/opt/ibm/icc/cimserver_planned.conf | grep traceFilePath)
        # value is #traceFilePath=/var/opt/ibm/icc/log/cimserver.trc
        value=${value##*=}
        cp -p -r $value $FOLDERNAME/platform_agent 1>/dev/null 2>&1
        cp -p -r /opt/ibm/platform/log/. $FOLDERNAME/platform_agent
    else [ "$OSType" = "AIX" ]
        #none
    fi
}

# *** grab other data****
grab_other_data() {
    echo "Collecting Other Data..."
    #grab meps data
    mkdir -p $FOLDERNAME/cli
    smcli $SMCLI_CREDENTIAL lsmeps > $FOLDERNAME/cli/lsmeps.txt
    meps=$(smcli $SMCLI_CREDENTIAL lsmeps | grep GUID)
    for guid in $meps; do 
        if [ $guid != "GUID:" ]; then
            smcli $SMCLI_CREDENTIAL lssystemdb $guid >> $FOLDERNAME/cli/lssystemdb.txt
        fi
    done
    
    smcli $SMCLI_CREDENTIAL lsupd -l > $FOLDERNAME/cli/lsupd.txt
    smcli $SMCLI_CREDENTIAL lsresources SoftwareInstallable > $FOLDERNAME/cli/lsresources_SoftwareInstallable.txt
    smcli $SMCLI_CREDENTIAL lsresources OperatingSystem > $FOLDERNAME/cli/lsresources_OperatingSystem.txt
    smcli $SMCLI_CREDENTIAL lsresources Server > $FOLDERNAME/cli/lsresources_Server.txt
    smcli $SMCLI_CREDENTIAL lsresources RemoteServiceAccessPoint > $FOLDERNAME/cli/lsresources_RemoteServiceAccessPoint.txt
    smcli $SMCLI_CREDENTIAL lsresources SoftwarePatch > $FOLDERNAME/cli/lsresources_SoftwarePatch.txt
    smcli $SMCLI_CREDENTIAL lsrelationships needs > $FOLDERNAME/cli/lsrelationships_needs.txt
    if [ "$OSType" = "Linux" ] ; then
        smcli $SMCLI_CREDENTIAL dumpmtp > $FOLDERNAME/cli/dumpmtp.txt
    fi
    #dump java core file
    smcli $SMCLI_CREDENTIAL dumpjava
    if [ "$OSType" = "Linux" ] ; then
        corefiles=$(ls --sort t /opt/ibm/director/lwi/runtime/core/javacore.*)
    else
        corefiles=$(ls -t /opt/ibm/director/lwi/runtime/core/javacore.*)
    fi   
    for corefile in $corefiles; do
        cp -p $corefile $FOLDERNAME/cli
        break
    done
    smcli $SMCLI_CREDENTIAL dumpstcfg 1>$FOLDERNAME/cli/dumpstcfg.txt 2>&1
    
    smcli $SMCLI_CREDENTIAL getAgentManagers > $FOLDERNAME/cli/getAgentManagers.txt
    ams=$(smcli $SMCLI_CREDENTIAL getAgentManagers | grep id/name | sed -e 's/.*id\/name : //')
    for guid in $ams; do
        smcli $SMCLI_CREDENTIAL getAgents $guid >> $FOLDERNAME/cli/getAgents.txt
    done
    smcli $SMCLI_CREDENTIAL queryAllAgents > $FOLDERNAME/cli/queryAllAgents.txt
    
    smcli $SMCLI_CREDENTIAL lssys -l > $FOLDERNAME/cli/lssys.txt

    smcli $SMCLI_CREDENTIAL lsevtlog -l > $FOLDERNAME/cli/lsevtlog.txt
    smcli $SMCLI_CREDENTIAL testCoreAgentQuery 127.0.0.1 9510 > $FOLDERNAME/cli/testCoreAgentQuery.txt
	
    #grab console job logs (*.def and matching *.log files in data directory)
    mkdir -p $FOLDERNAME/joblogs
    cp -p -r /opt/ibm/director/data/*.def $FOLDERNAME/joblogs 1>/dev/null 2>&1
    cp -p -r /opt/ibm/director/data/*.log $FOLDERNAME/joblogs
    
    # ***grab any advanced manager "failure to launch" logs ****
    cp -p -r /installLog.txt   $FOLDERNAME 1>/dev/null 2>&1
    # ***end grab any advanced manager "failure to launch" logs ****
    
    # ***grab TPC service.sh output ***
    if [ -f "/opt/IBM/TPC/service/service.sh" ]
    then
        mkdir -p $FOLDERNAME/tpc
        /opt/IBM/TPC/service/service.sh 1>/dev/null 2>&1
        cp -p /opt/IBM/TPC/service/TPCServiceFiles.zip $FOLDERNAME/tpc 1>/dev/null 2>&1
    fi
}

grab_system_info() {
    echo "Collecting System Information..."

    #Collect system information from the base system
    mkdir -p $FOLDERNAME/system_info
    ifconfig -a > $FOLDERNAME/system_info/ifconfig.txt
    netstat -an > $FOLDERNAME/system_info/netstat.txt
    hostname > $FOLDERNAME/system_info/hostname.txt
    uname -a > $FOLDERNAME/system_info/systeminfo.txt
    if [ "$OSType" = "Linux" ] ; then
        ps uxef > $FOLDERNAME/system_info/processes.txt
        /opt/ibm/icc/bin/slp_query --type="*" --address="127.0.0.1" > $FOLDERNAME/system_info/slp.txt
        iptables -L --line-numbers > $FOLDERNAME/system_info/firewall.txt
    else
        #aix
        ps -ef > $FOLDERNAME/system_info/processes.txt
        #127.0.0.1 does not work, get real IP
        ips=$(ifconfig -a | grep inet | grep -v '127.0.0.1' | awk '{print $2}')
        for ip in $ips; do
            #echo $ip
            /opt/freeware/cimom/pegasus/bin/slp_query --type="*" --address=$ip > $FOLDERNAME/system_info/slp.txt
            break
        done
        lsfilt > $FOLDERNAME/system_info/firewall.txt
    fi
    date > $FOLDERNAME/system_info/date.txt

}

# start grabbing
grab_configs
grab_version_files
grab_updatemgr_feature
grab_server_logs
grab_common_agent_logs
grab_platform_agent_logs
grab_other_data
grab_system_info

cd $FOLDERNAME
zip -r ../dirlogs-${HOSTNAME}-$DATEVAL.zip * 1>/dev/null 2>&1
if [ "$?" = "0" ]
then
    rm -rf $FOLDERNAME
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    echo IBM Systems Director logs are archived in $FOLDERNAME.zip.
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
else
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    echo IBM Systems Director logs are archived in $FOLDERNAME.
    echo Please use a zip tool to compress this folder, and then delete the contents.
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~    
fi
