@echo off

REM Licensed Materials - Property of IBM
REM OCO Source Materials
REM 09N6996
REM (C) Copyright IBM Corp. 2008, 2010 All Rights Reserved
REM The source code for this program is not published or other-
REM wise divested of its trade secrets, irrespective of what has
REM been deposited with the U.S. Copyright Office.

call setDirectorHome.bat
@echo Current date is %date% %time%
@echo DIRECTOR_HOME = %DIRECTOR_HOME%

for /f "tokens=2 delims==" %%a in ('wmic os get localdatetime /value') do (set ct=%%a)
set MM=%ct:~4,2%
set DD=%ct:~6,2%
set YY=%ct:~0,4%
set HH=%ct:~8,2%
set MIN=%ct:~10,2%
set SS=%ct:~12,2%

for /f "tokens=*" %%i in ('hostname') do (
    set TARGET=dirlogs-%%i-%YY%-%MM%-%DD%-%HH%-%MIN%-%SS%
)

::echo %TARGET%
rmdir %TARGET% /s /q >NUL 2>NUL
mkdir %TARGET%
   
if defined SMCLIUSER (
    if defined SMCLIPASSWORD (
        set SMCLI_CREDENTIAL=-user %SMCLIUSER% -pw %SMCLIPASSWORD%
    )
)

call:grab_configs
call:grab_version_files
call:grab_updatemgr_feature
call:grab_server_logs
call:grab_common_agent_logs
call:grab_platform_agent_logs
call:grab_other_data
call:grab_system_info

7z a %TARGET%.zip .\%TARGET%\* >NUL 2>NUL
if %ERRORLEVEL% == 0 (
    rmdir %TARGET% /s /q >NUL 2>NUL
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    echo IBM Systems Director logs are archived in %cd%\%TARGET%.zip 
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
) else (
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
    echo IBM Systems Director logs are archived in %cd%\%TARGET% 
    echo Please use a zip tool to compress this folder, and then delete the contents.
    echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
)
 

goto:eof

:: ***grab configs ***
:grab_configs
    echo "Collecting Configuration Data.."
    mkdir "%TARGET%\lwi\conf"
    copy "%DIRECTOR_HOME%lwi\conf\logging.properties" "%TARGET%\lwi\conf" >NUL 2>NUL
    mkdir "%TARGET%\lwi\conf\overrides"
    copy "%DIRECTOR_HOME%lwi\conf\overrides\logging.properties" "%TARGET%\lwi\conf\overrides" >NUL 2>NUL
    mkdir "%TARGET%\agent\conf"
    copy "%DIRECTOR_HOME%agent\conf\logging.properties" "%TARGET%\agent\conf" >NUL 2>NUL
    mkdir "%TARGET%\agent\conf\overrides"
    copy "%DIRECTOR_HOME%agent\conf\overrides\logging.properties" "%TARGET%\agent\conf\overrides" >NUL 2>NUL
goto:eof

:: ***grab version files
:grab_version_files
    echo "Collecting Director Version Data.."
    copy "%DIRECTOR_HOME%version.*" "%TARGET%" >NUL 2>NUL
goto:eof

:: ***grab update manager features
:grab_updatemgr_feature
    echo "Collecting Update Manager Feature Data.."
    call "%DIRECTOR_HOME%lwi\bin\lwiupdatemgr" -listFeatures > "%TARGET%\updatemgr_feature.txt"
    call "%DIRECTOR_HOME%agent\bin\lwiupdatemgr" -listFeatures > "%TARGET%\updatemgr_agent_feature.txt"
goto:eof

:: ***grab server logs
:grab_server_logs
    echo "Collecting Server Logs..."
    ::Primary log and trace files
    xcopy /E /Q "%DIRECTOR_HOME%lwi\logs" "%TARGET%" >NUL 2>NUL
    mkdir "%TARGET%\ffdc"
    ::copy entire ffdc directory
    xcopy /E /Q "%DIRECTOR_HOME%data\ffdc" "%TARGET%\ffdc" >NUL 2>NUL
    ::Ancillary log and trace files
    xcopy /E /Q "%DIRECTOR_HOME%log" "%TARGET%" >NUL 2>NUL

    mkdir "%TARGET%\agentmanager"
    xcopy /E /Q "%DIRECTOR_HOME%lwi\runtime\agentmanager\logs" "%TARGET%\agentmanager" >NUL 2>NUL
    xcopy /E /Q "%DIRECTOR_HOME%lwi\runtime\agentmanager\toolkit\logs" "%TARGET%\agentmanager" >NUL 2>NUL
    xcopy /E /Q "%DIRECTOR_HOME%lwi\runtime\core\logs" "%TARGET%" >NUL 2>NUL
    mkdir "%TARGET%\eccbase"
    xcopy /E /Q "%DIRECTOR_HOME%lwi\runtime\core\workspace\.metadata\.plugins\com.ibm.director.mgr.updates.server\ecc" "%TARGET%\eccbase" >NUL 2>NUL
    xcopy /E /Q "%DIRECTOR_HOME%tpm\config\logs" "%TARGET%" >NUL 2>NUL
    
    copy "%SYSTEMROOT%\dirinst.log" "%TARGET%" >NUL 2>NUL
    copy "%SYSTEMROOT%\dirserver*.log" "%TARGET%" >NUL 2>NUL
    copy "%SYSTEMROOT%\diragent*.log" "%TARGET%" >NUL 2>NUL
    copy "%SYSTEMROOT%\platinst*.log" "%TARGET%" >NUL 2>NUL
    copy "%SYSTEMROOT%\platuninst*.log" "%TARGET%" >NUL 2>NUL
    
    ::***grab migration logs from default location***
    mkdir "%TARGET%\migration"
    xcopy /E /Q "%APPDATA%\ISD61x\logs" "%TARGET%\migration" > NUL 2>NUL
    copy "%SYSTEMROOT%\migration.log" "%TARGET%\migration" >NUL 2>NUL

goto:eof

:: grab common agent logs
:grab_common_agent_logs
    echo "Collecting Common Agent Logs..."
    :: already created in grab_configs. mkdir "%TARGET%\agent"
    xcopy /E /Q "%DIRECTOR_HOME%agent\logs" "%TARGET%\agent" >NUL 2>NUL
    xcopy /E /Q "%DIRECTOR_HOME%agent\log"  "%TARGET%\agent" >NUL 2>NUL
    
    ::***grab CAS Agent service.bat output***
    call "%DIRECTOR_HOME%agent\runtime\agent\toolkit\bin\service.bat" >NUL 2>NUL
    copy "%DIRECTOR_HOME%agent\runtime\agent\CASservice.zip" "%TARGET%\agent" >NUL 2>NUL
    
goto:eof

:: *** grab platfrom(denali) agent
:grab_platform_agent_logs
    echo "Collecting Platform Agent Logs..."
    mkdir "%TARGET%\platform_agent"
    copy "%DIRECTOR_HOME%version.lv1" "%TARGET%\platform_agent" >NUL 2>NUL
    xcopy /E /Q "%ProgramFiles%\Common Files\ibm\icc\log\*.log"  "%TARGET%\platform_agent" >NUL 2>NUL
    xcopy /E /Q "%ProgramFiles%\Common Files\ibm\icc\cimom\bin\*.log"  "%TARGET%\platform_agent" >NUL 2>NUL
    copy "%DIRECTOR_HOME%cimom\log\ibm-ipmi.log" "%TARGET%\platform_agent" >NUL 2>NUL
    xcopy /E /Q "%DIRECTOR_HOME%cimom\log\adptlogs" "%TARGET%\platform_agent" >NUL 2>NUL
goto:eof

:: *** grab other data****
:grab_other_data
    echo "Collecting Other Data..."
    mkdir "%TARGET%\cli"
    
    ::grab meps data
    smcli %SMCLI_CREDENTIAL% lsmeps > "%TARGET%\cli\lsmeps.txt"
    for /f  "tokens=2 delims= " %%i in ( 'findstr "GUID" "%TARGET%\cli\lsmeps.txt"') do (
        smcli %SMCLI_CREDENTIAL% lssystemdb %%i >> "%TARGET%\cli\lssystemdb.txt"
    )
    
    smcli %SMCLI_CREDENTIAL% lsupd -l > "%TARGET%\cli\lsupd.txt"
    smcli %SMCLI_CREDENTIAL% lsresources SoftwareInstallable > "%TARGET%\cli\lsresources_SoftwareInstallable.txt"
    smcli %SMCLI_CREDENTIAL% lsresources OperatingSystem > "%TARGET%\cli\lsresources_OperatingSystem.txt"
    smcli %SMCLI_CREDENTIAL% lsresources Server > "%TARGET%\cli\lsresources_Server.txt"
    smcli %SMCLI_CREDENTIAL% lsresources RemoteServiceAccessPoint > "%TARGET%\cli\lsresources_RemoteServiceAccessPoint.txt"
    smcli %SMCLI_CREDENTIAL% lsresources SoftwarePatch > "%TARGET%\cli\lsresources_SoftwarePatch.txt"
    smcli %SMCLI_CREDENTIAL% lsrelationships needs > "%TARGET%\cli\lsrelationships_needs.txt"
    smcli %SMCLI_CREDENTIAL% dumpmtp > "%TARGET%\cli\dumpmtp.txt"
   
    ::get latest javacore file
    smcli %SMCLI_CREDENTIAL% dumpjava
    for /f  %%i in ( 'dir /B /OD "%DIRECTOR_HOME%lwi\runtime\core\javacore*"') do (
        set corefile=%%i
    )
    copy "%DIRECTOR_HOME%lwi\runtime\core\%corefile%" "%TARGET%\cli" >NUL 2>NUL
    smcli %SMCLI_CREDENTIAL% dumpstcfg 1>"%TARGET%\cli\dumpstcfg.txt" 2<&1
    
    smcli %SMCLI_CREDENTIAL% getAgentManagers >  "%TARGET%\cli\getAgentManagers.txt"
    for /f "tokens=2 delims=:" %%i in ( 'findstr "id/name" "%TARGET%\cli\getAgentManagers.txt"') do (
        smcli %SMCLI_CREDENTIAL% getAgents %%i >> "%TARGET%\cli\getAgents.txt"
    )
    smcli %SMCLI_CREDENTIAL% queryAllAgents > "%TARGET%\cli\queryAllAgents.txt"
	
    smcli %SMCLI_CREDENTIAL% lssys -l >  "%TARGET%\cli\lssys.txt"

    smcli %SMCLI_CREDENTIAL% lsevtlog -l >  "%TARGET%\cli\lsevtlog.txt"
    smcli %SMCLI_CREDENTIAL% testCoreAgentQuery 127.0.0.1 9510 >  "%TARGET%\cli\testCoreAgentQuery.txt"
    
    ::grab console job logs (*.def and matching *.log files in data directory)
    mkdir "%TARGET%\joblogs"
    
    copy "%DIRECTOR_HOME%data\*.def" "%TARGET%\joblogs" >NUL 2>NUL
    copy "%DIRECTOR_HOME%data\*.log" "%TARGET%\joblogs" >NUL 2>NUL

    ::***grab  advanced manager "failure to launch" logs****
    xcopy /E /Q "%USERPROFILE%\Desktop\installLog.txt" "%TARGET%" >NUL 2>NUL
    
    ::***grab TPC service.bat output***
    if exist "%ProgramFiles%\IBM\TPC\service\service.bat" (
        mkdir "%TARGET%\tpc"
        call "%ProgramFiles%\IBM\TPC\service\service.bat" >NUL 2>NUL
        copy "%ProgramFiles%\IBM\TPC\service\TPCServiceFiles.zip" "%TARGET%\tpc" >NUL 2>NUL
    )
goto:eof

:grab_system_info
    echo "Collecting System Information..."
    
    ::Collect system information from the base system
    mkdir "%TARGET%\system_info"
    ipconfig /all > "%TARGET%\system_info\ipconfig.txt"
    netstat -an > "%TARGET%\system_info\netstat.txt"
    hostname > "%TARGET%\system_info\hostname.txt"
    systeminfo > "%TARGET%\system_info\systeminfo.txt"
    tasklist /V /FO List > "%TARGET%\system_info\processes.txt"

    date /t > "%TARGET%\system_info\date.txt"
    time /t >> "%TARGET%\system_info\date.txt"
    
    "%ProgramFiles%\Common Files\ibm\icc\slp\bin\slp_query" --type="*" --address="127.0.0.1" > "%TARGET%\system_info\slp.txt"
    
    netsh firewall show config > "%TARGET%\system_info\firewall.txt"
goto:eof
